@@ -1,19 +1,28 @@
 # -*- coding: utf-8 -*-
-
+"""
+Core client for requesting Hi-net waveform data.
+"""
 import os
 import re
+import csv
+import json
 import time
+import shutil
 import logging
 import tempfile
 import zipfile
 from datetime import datetime, timedelta
 from multiprocessing.pool import ThreadPool
+from distutils.version import LooseVersion
+
 
 import requests
 
 from .win32 import merge
 from .header import NETWORK
 from .utils import point_inside_box, point_inside_circular, split_integer, to_datetime
+from ._version import get_versions
+
 
 # Setup the logger
 FORMAT = "[%(asctime)s] %(levelname)s: %(message)s"
@@ -22,6 +31,10 @@ logger = logging.getLogger(__name__)
 
 
 class Client:
+    """
+    Core client for requesting Hi-net waveform data.
+    """
+
     # Hinet website
     _HINET = "http://www.hinet.bosai.go.jp/"
     # Authorization page
@@ -150,7 +163,7 @@ class Client:
             raise requests.ConnectionError(msg)
 
     def doctor(self):
-        """ Doctor does some checks.
+        """Doctor does some checks.
 
         :meth:`~HinetPy.client.Client.doctor` is a utility function which checks:
 
@@ -798,7 +811,7 @@ class Client:
                     region=region,
                     magmin=minmagnitude,
                     magmax=maxmagnitude,
-                    include_unknown_mag=True,
+                    include_unknown_mag=include_unknown_mag,
                 )
             )
 
@@ -961,8 +974,6 @@ class Client:
         # remove trailing 'A' in network code
         code = code[:4]
         if code in ["0101", "0103", "0103A"]:  # Hinet and Fnet
-            import csv
-
             lines = (
                 requests.get(self._STATION_INFO).content.decode("utf-8").splitlines()
             )
@@ -982,8 +993,6 @@ class Client:
                     )
                 )
         elif code in ["0120", "0120A", "0131"]:  # S-net and MeSO-net
-            import json
-
             if code in ["0120", "0120A"]:
                 json_text = (
                     self.session.get(self._SNET_STATION_INFO)
@@ -1192,9 +1201,9 @@ class Client:
         if r.headers["ETag"].strip('"') == self._ETAG:
             logger.info("Hi-net web service is NOT updated.")
             return False
-        else:
-            logger.warning("Hi-net web service is updated. HinetPy may FAIL!")
-            return True
+
+        logger.warning("Hi-net web service is updated. HinetPy may FAIL!")
+        return True
 
     def check_package_release(self):
         """Check whether HinetPy has a new release.
@@ -1202,9 +1211,6 @@ class Client:
         >>> client.check_package_release()
         [2019-12-06 00:00:00] INFO: You're using the latest release (v0.6.5).
         """
-        from HinetPy import __version__
-        from distutils.version import LooseVersion
-
         url = "https://pypi.python.org/pypi/HinetPy/json"
         r = requests.get(url)
         if r.status_code != 200:
@@ -1212,14 +1218,15 @@ class Client:
             return False
         latest_release = r.json()["info"]["version"]
 
-        if LooseVersion(latest_release) > LooseVersion(__version__):
+        current_version = get_versions()["version"]
+        if LooseVersion(latest_release) > LooseVersion(current_version):
             logger.warning(
                 f"HinetPy v{latest_release} is released. See {url} for details."
             )
             return True
-        else:
-            logger.info(f"You're using the latest version (v{__version__}).")
-            return False
+
+        logger.info(f"You're using the latest version (v{current_version}).")
+        return False
 
     def check_cmd_exists(self):
         """Check if ``catwin32`` and ``win2sac_32`` from win32tools in PATH.
@@ -1233,8 +1240,6 @@ class Client:
         `Hi-net <http://www.hinet.bosai.go.jp/>`_
         and make sure both binary files are in your PATH.
         """
-        import shutil
-
         error = 0
         for cmd in ("catwin32", "win2sac_32"):
             fullpath = shutil.which(cmd)
@@ -1329,7 +1334,7 @@ def prepare_jobs(starttime, span, max_span):
     return jobs
 
 
-class _Job(object):
+class _Job:
     """Job class for internal use."""
 
     def __init__(self, starttime, span, id=None):
@@ -1338,7 +1343,7 @@ class _Job(object):
         self.id = id
 
 
-class Station(object):
+class Station:
     """
     Class for Stations.
     """
@@ -1357,7 +1362,7 @@ class Station(object):
         return string
 
 
-class Event(object):
+class Event:
     """
     Event class for requesting event waveforms.
     """
@@ -1393,17 +1398,17 @@ def _parse_code(code):
     """Parse network code.
 
     >>> client._parse_code('0101')
-    ('01', '01', None)
+    ('01', '01', '0')
     >>> client._parse_code('0103A')
-    ('01', '03A', None)
+    ('01', '03A', '0')
     >>> client._parse_code('010501')
     ('01', '05', '010501')
     """
     if code not in NETWORK.keys():
         raise ValueError(f"{code}: Incorrect network code.")
-    elif code.startswith("0105") or code.startswith("0302"):
+
+    if code.startswith("0105") or code.startswith("0302"):
         org, net, volc = code[0:2], code[2:4], code
     else:
-        org, net, volc = code[0:2], code[2:], None
-
+        org, net, volc = code[0:2], code[2:], "0"
     return org, net, volc
